==> wechaty-plugin-contrib-0.0.7.tar.gz: wechaty-plugin-contrib-0.0.7/src/wechaty_plugin_contrib/finders/room_finder.py <==
"""Room Finder to match the specific Room"""
import re
from re import Pattern
import inspect
from typing import List

from wechaty_plugin_contrib.config import (
    get_logger,
    Room,

    Wechaty
)

from .finder import Finder


logger = get_logger("RoomFinder")


class RoomFinder(Finder):
    async def match(self, wechaty: Wechaty) -> List[Room]:
        """match the room"""
        logger.info(f'RoomFinder match({Wechaty})')

        rooms: List[Room] = []

        for option in self.options:
            if isinstance(option, Pattern):

                # search from all of the friends
                # match the room with regex pattern
                all_rooms = await wechaty.Room.find_all()
                for room in all_rooms:
                    topic = await room.topic()
                    if re.match(option, topic):
                        rooms.append(room)

            elif isinstance(option, str):
                room = wechaty.Room.load(option)
                await room.ready()
                rooms.append(room)
            elif hasattr(option, '__call__'):
                """check the type of the function
                refer: https://stackoverflow.com/a/56240578/6894382
                """
                if inspect.iscoroutinefunction(option):
                    # pytype: disable=bad-return-type
                    targets = await option(wechaty)
                else:
                    targets = option(wechaty)
                if isinstance(targets, List[Room]):
                    rooms.extend(targets)
            else:
                raise ValueError(f'unknown type option: {option}')
        return rooms

==> wechaty-plugin-contrib-0.0.12.tar.gz: wechaty-plugin-contrib-0.0.12/src/wechaty_plugin_contrib/finders/room_finder.py <==
"""Room Finder to match the specific Room"""
from __future__ import annotations

import re
from re import Pattern
import inspect
from typing import List

from wechaty_plugin_contrib.config import (
    get_logger,
    Room,
    Wechaty
)

from .finder import Finder


logger = get_logger("RoomFinder")


class RoomFinder(Finder):
    """Room Finder can find rooms"""
    async def match(self, wechaty: Wechaty) -> List[Room]:
        """match the room"""
        logger.info(f'RoomFinder match({Wechaty})')

        rooms: List[Room] = []

        for option in self.options:
            if isinstance(option, Pattern):

                # search from all of the friends
                # match the room with regex pattern
                all_rooms = await wechaty.Room.find_all()
                for room in all_rooms:
                    topic = await room.topic()
                    if re.match(option, topic):
                        rooms.append(room)

            elif isinstance(option, str):
                room = wechaty.Room.load(option)
                await room.ready()
                rooms.append(room)
            # TODO: implement callback function to find rooms
            # elif hasattr(option, '__call__'):
            #     """check the type of the function
            #     refer: https://stackoverflow.com/a/56240578/6894382
            #     """
            #     if inspect.iscoroutinefunction(option):
            #         # pytype: disable=bad-return-type
            #         targets = await option(wechaty)
            #     else:
            #         targets = option(wechaty)
            #     if isinstance(targets, List[Room]):
            #         rooms.extend(targets)
            else:
                raise ValueError(f'unknown type option: {option}')
        return rooms
